## Dati stimati per un auto. La rapportatura del cambio sarà calcolata
## in modo da ottimizzare l'intero range di velocità.

m = 1100;                     ## [kg] - massa totale veicolo + pilota
p = 2.5;                      ## [m] - passo del veicolo
b = linspace(0.7,1.7,30);     ## [m] - distanza baricentro dall'asse posteriore
h = linspace(0.2,0.8,30);     ## [m] - altezza baricentro
Rr = 0.308;                   ## [m] - raggio ruota posteriore
Rf = 0.308;                   ## [m] - raggio ruota anteriore
I_r = 1.7;                    ## [kg m^2] - Inerzia ruota posteriore
I_f = 1.7;                    ## [kg m^2] - Inerzia ruota anteriore
I_m = 0.12;                   ## [kg m^2] - Inerzia motore ridotta all'albero
I_p = 0.01;                   ## [kg m^2] - Inerzia cambio albero primario
I_s = 0.02;                   ## [kg m^2] - Inerzia cambio albero secondario
R_p = 1;                      ## Rapporto primario [w_albero_motore/w_primario_cambio]
R_f = 1;                      ## Rapporto finale [w_secondario_cambio/w_ruota]
## matrice coppia motore. La prima riga contiene il regime di rotazione del
## motore [rpm], la seconda riga il valore di coppia a quel regime [Nm]
CC = [1, 225, 450, 675, 900, 1125, 1350, 1575, 1800, 2025, 2250, 2475, 2700, 2925, 3150, 3375, 3600, 3825, 4050, 4275, 4500, 4725, 4950, 5175, 5400, 5625, 5850, 6075, 6300;
      50, 70, 80, 88, 92, 95, 98, 102, 110, 115, 120, 125, 130, 138, 145, 152, 158, 162, 163.2, 163.2, 162, 161, 159, 157, 155, 153, 147, 139, 127];
rs = 6300;          ## [rpm] - regime di cambio marcia
Af = 2.3;           ## [m^2] - area frontale
Cd = 0.28;          ## Coefficiente di resistenza aerodinamica
Cl = -1;            ## Coefficiente di portanza aerodinamica
Cm = 0;             ## Coefficiente di momento aerodinamico. Negativo = picchiante.
                    ## Si considera già moltiplicato per la corda del profilo.
rho = 1.2;          ## [kg/m^3] - densita' dell'aria
mu = 0.5;           ## coefficiente di attrito gomma/asfalto
mur = 0.03;         ## coefficiente resistenza rotolamento
alpha = 0;          ## [rad] - inclinazione strada
Lr = 400;           ## [m] - lunghezza del tratto rettilineo
vi = 60/3.6;        ## [m/s] - velocita' iniziale
vf = 60/3.6;        ## [m/s] - velocita' finale
ns = 400;           ## numero di suddivisioni del tratto rettilineo
fdu = "fr";         ## freno da utilizzare
tr = "r";           ## trazione. f=front, r=rear

## Calcolo i rapporti del cambio in modo da ottimizzare l'intero range di velocità
P = CC(1,:)*2*pi/60.*CC(2,:);       ## Vettore potenze
Pm = max(P);                        ## Potenza massima [W]
rpm_Pm = max((P==Pm).*CC(1,:));     ## regime di potenza massima [rpm]
v_teor = (2*Pm/(rho*Cd*Af))^(1/3);  ## velocità massima teorica [m/s]
v_prima = Pm/m/9.8/mu;              ## Velocità desiderata in prima marcia [m/s]

## Velocità di rotazione ruota motrice
if tr =="r"
 w_6 = v_teor/Rr;
 w_1 = v_prima/Rr;
elseif tr == "f"
 w_6 = v_teor/Rf;
 w_1 = v_prima/Rr;
endif

R6 = rpm_Pm*2*pi/60/w_6;                        ## Rapporto totale sesta marcia
R1 = rpm_Pm*2*pi/60/w_1;                        ## Rapporto totale prima marcia

## Successione armonica
a = 1/R1;                                       ## Primo termine
d = (1/R6 - a)/5;                               ## Secondo termine
Rc = [1/a, 1/(a+d), 1/(a+2*d), 1/(a+3*d), 1/(a+4*d), 1/(a+5*d)];
