## Dati stimati per una moto da 1000 cc. La rapportatura del cambio sarà calcolata
## in modo da ottimizzare l'intero range di velocità.

m = 290;                      ## [kg] - massa totale veicolo + pilota
p = 1.45;                     ## [m] - passo del veicolo
b = linspace(0.4,1,30);       ## [m] - distanza baricentro dall'asse posteriore
h = linspace(0.4,1,30);       ## [m] - altezza baricentro
Rr = 0.315;                   ## [m] - raggio ruota posteriore
Rf = 0.3;                     ## [m] - raggio ruota anteriore
I_r = 0.65;                   ## [kg m^2] - Inerzia ruota posteriore
I_f = 0.45;                   ## [kg m^2] - Inerzia ruota anteriore
I_m = 0.05;                   ## [kg m^2] - Inerzia motore ridotta all'albero
I_p = 0.005;                  ## [kg m^2] - Inerzia cambio albero primario
I_s = 0.007;                  ## [kg m^2] - Inerzia cambio albero secondario
R_p = 1;                      ## Rapporto primario [w_albero_motore/w_primario_cambio]
R_f = 1;                      ## Rapporto finale [w_secondario_cambio/w_ruota]
## matrice coppia motore. La prima riga contiene il regime di rotazione del
## motore [rpm], la seconda riga il valore di coppia a quel regime [Nm]
CC = [1, 500, 1000, 1500, 2000, 2500, 3000, 3500, 4000, 4500, 5000, 5500, 6000, 6500, 7000, 7500, 8000, 8500, 9000, 9500, 10000, 10500, 11000, 11500, 12000, 12500, 13000, 13500, 14000;
      43.35, 46.75, 50.15, 53.55, 55.25, 56.95, 58.65, 60.35, 62.05, 62.9, 63.24, 63.58, 63.92, 64.26, 64.06, 65.45, 66.3, 67.15, 68, 68, 67.49, 66.98, 66.47, 65.62, 64.77, 63.92, 61.2, 57.8, 52.7];
rs = 14000;         ## [rpm] - regime di cambio marcia
Af = 0.7;           ## [m^2] - area frontale
Cd = 0.38;          ## Coefficiente di resistenza aerodinamica
Cl = 0;             ## Coefficiente di portanza aerodinamica
Cm = 0;             ## Coefficiente di momento aerodinamico. Negativo = picchiante.
                    ## Si considera già moltiplicato per la corda del profilo.
rho = 1.2;          ## [kg/m^3] - densita' dell'aria
mu = 0.5;           ## coefficiente di attrito gomma/asfalto
mur = 0.015;        ## coefficiente resistenza rotolamento
alpha = 0;          ## [rad] - inclinazione strada
Lr = 400;           ## [m] - lunghezza del tratto rettilineo
vi = 60/3.6;        ## [m/s] - velocita' iniziale
vf = 60/3.6;        ## [m/s] - velocita' finale
ns = 400;           ## numero di suddivisioni del tratto rettilineo
fdu = "fr";          ## freno da utilizzare
tr = "r";           ## trazione. f=front, r=rear

## Calcolo i rapporti del cambio in modo da ottimizzare l'intero range di velocità
P = CC(1,:)*2*pi/60.*CC(2,:);       ## Vettore potenze
Pm = max(P);                        ## Potenza massima [W]
rpm_Pm = max((P==Pm).*CC(1,:));     ## regime di potenza massima [rpm]
v_teor = (2*Pm/(rho*Cd*Af))^(1/3);  ## velocità massima teorica [m/s]
v_prima = Pm/m/9.8/mu;              ## Velocità desiderata in prima marcia [m/s]

## Velocità di rotazione ruota motrice
if tr =="r"
 w_6 = v_teor/Rr;
 w_1 = v_prima/Rr;
elseif tr == "f"
 w_6 = v_teor/Rf;
 w_1 = v_prima/Rr;
endif

R6 = rpm_Pm*2*pi/60/w_6;                        ## Rapporto totale sesta marcia
R1 = rpm_Pm*2*pi/60/w_1;                        ## Rapporto totale prima marcia

## Successione armonica
a = 1/R1;                                       ## Primo termine
d = (1/R6 - a)/5;                               ## Secondo termine
Rc = [1/a, 1/(a+d), 1/(a+2*d), 1/(a+3*d), 1/(a+4*d), 1/(a+5*d)];
